@@ -2491,12 +2491,3 @@ Magick::VPathBase* Magick::PathMovetoRel::copy() const
 {
   return new PathMovetoRel(*this);
 }
-
-#if defined(EXPLICIT_TEMPLATE_INSTANTIATION)
-// template class std::vector<Magick::Coordinate>;
-// template class std::vector<const Magick::Drawable>;
-// template class std::vector<const Magick::PathArcArgs>;
-// template class std::vector<const Magick::PathCurvetoArgs>;
-// template class std::vector<const Magick::PathQuadraticCurvetoArgs>;
-// template class std::vector<const Magick::VPath>;
-#endif
